@extends('layouts.dashboard')

@section('styles')
    <link href="{{ asset('css/select2.min.css') }}" rel="stylesheet">
@endsection
@section('content')
    <div class="d-flex justify-content-between">
        <div>
            <h1>Report</h1>
            <p>The report below will show only those records that have matching <i>SKU</i> in <i>Inventory</i> and matching
                <i>Tracking Number</i> in shipment</p>

        </div>
        <div>
            <a class="btn btn-primary font-12px"
                href="{{ count($selected_values) > 0 ? route('report.export', $selected_values) : '#' }}"
                role="button">Export</a>
        </div>
    </div>
    <hr>



    <div class="d-flex justify-content-between">

        <form class="form-inline">
            <div class="form-group mb-2">
                <select class="form-control dd font-12px multiselectDD" multiple="multiple" id="PONumberMultiselect">
                    @for ($index = 0; $index < count($allPoNumbers); $index++)
                        <option value="{{ $allPoNumbers[$index] }}">{{ $allPoNumbers[$index] }}</option>
                    @endfor
                </select>
            </div>
            <button type="button" class="btn btn-primary mb-2 mx-sm-3 font-12px" onclick="getSelectedPOs()">Filter</button>
        </form>
        <form class="form-inline">
            <div class="form-group mb-2">

                <select class="form-control dd font-12px" id="monthdd">
                    <option value="">Select Month</option>
                    @for ($index = 0; $index < count($months); $index++)
                        <option value="{{ $index + 1 }}" {{ request()->get('month') == $index + 1 ? 'selected' : '' }}>
                            {{ $months[$index] }}</option>
                    @endfor
                </select>

            </div>
            <div class="form-group mx-sm-3 mb-2">
                <select class="form-control dd font-12px" id="yeardd">
                    <option value="">Select Year</option>
                    @for ($index = 0; $index < count($years); $index++)
                        <option value="{{ $years[$index] }}"
                            {{ request()->get('year') == $years[$index] ? 'selected' : '' }}>{{ $years[$index] }}</option>
                    @endfor
                </select>
            </div>
            <button type="button" class="btn btn-primary mb-2 font-12px" disabled id="filterBtn">Filter</button>
        </form>
    </div>


    <div class="table-responsive  decrease-pad">
        <table class="table">
            <thead>
                <tr>
                    <th scope="col">#</th>
                    <th scope="col">PO#</th>
                    <th scope="col">Order#</th>
                    <th scope="col">Order Date</th>
                    <th scope="col">Tracking Number</th>
                    <th scope="col">Ship By</th>
                    <th scope="col">Delivery Date</th>
                    <th scope="col">Customer Name</th>
                    <th scope="col">Status</th>
                    <th scope="col">Sale Price</th>
                    <th scope="col">Total Cost</th>
                    <th scope="col">Shipping Cost</th>
                    <th scope="col">Comission 15%</th>
                    <th scope="col">Total Exp</th>
                    <th scope="col">Profit & Loss</th>
                    <th scope="col">Profit %</th>
                    <th scope="col">ROI</th>
                    <th scope="col"></th>
                </tr>
            </thead>
            <tbody>
                @foreach ($report as $data)
                    <tr class="{{ $data->profit_or_loss < 0 ? 'text-light' : '' }}">
                        <th scope="row">
                            {{ isset($currentPage) ? $pagging->perPage() * ($currentPage - 1) + ($loop->index + 1) : $loop->index + 1 }}
                        </th>
                        <td><a href="{{ route('purchase-order.details', $data->po_number) }}"
                                class="order-number">{{ $data->po_number }}</a></td>

                        <td>{{ $data->order_number }}</td>
                        <td>{{ $data->order_date }}</td>
                        <td>{{ $data->tracking_number }}</td>
                        <td>{{ $data->ship_by }}</td>
                        <td>{{ $data->delivery_date }}</td>
                        <td>{{ $data->customer_name }}</td>
                        <td>{{ $data->status }}</td>
                        <td>{{ $data->total_sales_price }}</td>
                        <td>${{ $data->total_cost }}</td>
                        <td>{{ $data->shipping_cost }}</td>
                        <td>${{ $data->commission }}</td>
                        <td>${{ $data->total_expenses }}</td>
                        <td>${{ $data->profit_or_loss }}</td>
                        <td>{{ $data->profit_percent }}%</td>
                        <td>{{ $data->ROI }}%</td>
                        <td>
                            <button type="button" class="btn btn-primary btn-sm" data-toggle="modal"
                                onclick="callMe('{{ $data->tracking_number }}')">Order Items</button>

                            @include('report.order-item-details', [
                                'orderItems' => $orderItems[$data->tracking_number],
                                'trackingNumber' => $data->tracking_number,
                            ])
                        </td>
                    </tr>
                @endforeach
            </tbody>
        </table>
    </div>


    <div class="table-responsive">
        <table class="table text-center">
            <thead>
                <tr>
                    <th scope="col">Qty</th>
                    <th scope="col">Sales Price</th>
                    <th scope="col">Shipping Cost</th>
                    <th scope="col">Commission</th>
                    <th scope="col">Expenses</th>
                    <th scope="col">Profit or Loss</th>
                </tr>
            </thead>
            <tbody>

                <tr>
                    <td>{{ $summary_row_data->qty }}</td>
                    <td>{{ $summary_row_data->sales_price_total }}</td>
                    <td>{{ $summary_row_data->shipping_cost_total }}</td>
                    <td>{{ $summary_row_data->commission_total }}</td>
                    <td>{{ $summary_row_data->expenses_total }}</td>
                    <td>{{ $summary_row_data->profit_or_loss_total }}</td>
                </tr>
            </tbody>
        </table>
    </div>

    <div class="d-flex justify-content-center py-3">
        <?php
        unset($selected_values['download']);
        ?>
        {{ $pagging->appends($selected_values)->Links() }}
    </div>
@endsection

@section('scripts')
    <script src="{{ asset('js/select2.min.js') }}" defer></script>
    <script>
        $(document).ready(function() {
            let params = new URLSearchParams(window.location.search)
            const pos = params.get('po')
            const PONumberDD = $("#PONumberMultiselect");
            $(".multiselectDD").select2({
                placeholder: "Filter By POs",
            });

            if (pos) {
                $("#PONumberMultiselect").val(pos.split(','))
                $("#PONumberMultiselect").trigger('change')
            }
        });

        function getSelectedPOs() {
           const query_param = getQueryOfURL();
            const selectedValues = $('#PONumberMultiselect').select2('data');
            const pos = selectedValues.map((item) => item.text);
            let redirectWitFilters = `/report?po=${pos.join(',')}`;
            if (query_param !=="") redirectWitFilters = `${redirectWitFilters}&${query_param}`;
            window.location = redirectWitFilters;
        }

        function getQueryOfURL() {
            const year = $("#yeardd").val();
            const month = $("#monthdd").val();
            let query_param = ""
            if (year != "" && month != "") {
                query_param = `month=${month}&year=${year}`
            } else
            if (month != "") {
                query_param = `month=${month}`
            } else if (year != "") {
                query_param = `year=${year}`
            }
            return query_param;
        }
    </script>
    <script>
        function callMe(id) {
            $(`#${id}Modal`).modal('show')
        }

        $(document).ready(function() {
            $(".dd").change(function() {
                const year = $("#yeardd").val();
                const month = $("#monthdd").val();
                if (year == "" && month == "") {
                    $("#filterBtn").prop('disabled', true)
                } else {
                    $("#filterBtn").prop('disabled', false)
                }
            });

            $("#filterBtn").on("click", function() {
              const query_param = getQueryOfURL();
                window.location = `/report?${query_param}`
            });

        }) // document end
    </script>
@endsection
