@extends('layouts.dashboard')

@section('styles')
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
@endsection

@section('content')

<h1>SKU Report</h1>
<div>
    <div class="card" >
      <div class="card-body">
        <div class="form-group mb-2">
        <select class="form-control" id="multiSelect" multiple="multiple">
          @foreach ($inventories as $key => $obj)
          <option {{in_array($obj['id'], $inventory_ids_arr) ? 'selected' : ''}} value="{{$obj['id']}}">{{$obj['title']}} | {{$obj['msku']}}</option>
          @endforeach  
        </select>
        </div>
        <form class="form-inline">
  <div class="form-group mb-2">

<select class="form-control dd font-12px" id="monthdd">
  <option value="">Select Month</option>
  @for($index = 0; $index < count($months); $index++)
  <option value="{{$index+1}}" {{ request()->get('month') == $index+1 ? "selected" : "" }}>{{$months[$index]}}</option>
@endfor
</select>

  </div>
  <div class="form-group mx-sm-3 mb-2">
    <select class="form-control dd font-12px" id="yeardd">
      <option value="">Select Year</option>
      @for($index = 0; $index < count($years); $index++)
        <option value="{{$years[$index]}}" {{ request()->get('year') == $years[$index] ? "selected" : "" }}>{{$years[$index]}}</option>
      @endfor
    </select>
  </div>
  <button type="button" class="btn btn-primary mb-2 font-12px" disabled id="filterBtn" >Filter</button>
</form>

    </div>
</div>


</div>

<div class="table-responsive decrease-pad">
<table class="table text-center">
  <thead>
    <tr>      
      <th scope="col">SKU</th>
      <th scope="col">Qty</th>
      <th scope="col">Sale Price</th>
      <th scope="col">Cost</th>
      <th scope="col">Shipping Cost</th>
      <th scope="col">Comission 15%</th>
      <th scope="col">Total Exp</th>
      <th scope="col">Profit & Loss</th>
    </tr>
  </thead>
  <tbody>
    @foreach ($yearly_report as $key => $obj)
    <tr>
      <th class="text-left">{{$obj->title}} | {{ $key }}</th>
      <td>{{ number_format((float) $obj->qty_total, 2, '.', ',')}}</td>
      <td>${{ number_format((float) $obj->sales_price_total, 2, '.', ',')}}</td>
      <td>${{ number_format((float) $obj->cost_total, 2, '.', ',')}}</td>
      <td>${{ number_format((float) $obj->shipping_cost_total, 2, '.', ',')}}</td>
      <td>${{ number_format((float) $obj->commission_total, 2, '.', ',')}}</td>
      <td>${{ number_format((float) $obj->expenses_total, 2, '.', ',')}}</td>
      <td>${{ number_format((float) $obj->profit_or_loss_total, 2, '.', ',')}}</td>
    </tr>
     @endforeach       
  </tbody>
</table>

<div class="d-flex justify-content-center py-3">
  {{ $results->appends($selected_values)->Links() }}
</div>

</div>
@endsection
@section('scripts')
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js" defer></script>

<script>
    function enableFilterBtn(){
    const year = $("#yeardd").val() ;
      const month = $("#monthdd").val();
      const skus_ids = $('#multiSelect').select2("val")

      if((month == "" ||  year == "") && skus_ids.length == 0){
        $("#filterBtn").prop('disabled', true)
      }
      else{
        $("#filterBtn").prop('disabled', false)
      }
  }
 $(document).ready(function(){

  $('#multiSelect').select2({
    //multiple: true,
    placeholder: "Select a SKU",
}).on("change", function (e) {
  enableFilterBtn();
});
   $(".dd").change(function () {
    enableFilterBtn();     
    });
    $("#filterBtn").on("click",function(){
      let query_param = "";
      const skus_ids = $('#multiSelect').select2("val")
        const year = $("#yeardd").val();
        const month = $("#monthdd").val();
      if(skus_ids.length){
        query_param = `skus=${skus_ids.join()}`
      }

      if(year != "" && month != ""){
        query_param += `${query_param != "" ? '&' : ''}year=${year}&month=${month}`
      }
        window.location = `/sku-report?${query_param}`
  });
 })// document end
</script>
@endsection

