<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\PurchaseOrder;
use App\Inventory;
use App\Shipment;


class PurchaseOrderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
      $currentPage = $request['page'];
        $purchaseOrders;
        if ( $request->has('search')) {
            $search = trim($request->input('search'));
            $query = PurchaseOrder::where('tracking_number', 'LIKE', "%$search%");
            $query = $query->orWhere('po_number', 'LIKE', "%$search%");
            $query = $query->orWhere('customer_name', 'LIKE', "%$search%");
           $purchaseOrders = $query->paginate(15);
          }
        else{
          $purchaseOrders = PurchaseOrder::paginate(15);
        }
        $data = [
          'purchaseOrders'  => $purchaseOrders,
          'currentPage'  => $currentPage,
      ];
         return view('purchase-order.index')
       ->with( $data);
    }

    public function missing(Request $request)
    {
      $currentPage = $request['page'];
      // records having no tracking number in shipment
         $query = PurchaseOrder::whereDoesntHave('shipment');
        
        if ( $request->has('search')) {
            $search = trim($request->input('search'));
            $query = $query->where('tracking_number', 'LIKE', "%$search%");
            $query = $query->orWhere('po_number', 'LIKE', "%$search%");
            $query = $query->orWhere('customer_name', 'LIKE', "%$search%");
        }        
        $query = $query->groupBy("tracking_number");
        // $query = $query->where('is_available', 0);
        $missingShipmentsCountQuery = clone $query;
        $missingShipmentsCount = $missingShipmentsCountQuery->get();
        $missingShipmentsCount =count($missingShipmentsCount);
         $missingShipments = $query->paginate(15);

        $data = [
        'purchaseOrders'  => $missingShipments,
        'missingShipmentsCount'  => $missingShipmentsCount,
        'currentPage'  => $currentPage,
    ];

         return view('purchase-order.add-missing-tracking-number')
       ->with( $data);
    }

    public function missingSKUsInInventory(Request $request)
    {
      $currentPage = $request['page'];
      $query = PurchaseOrder::whereDoesntHave('inventory');
     
        if ( $request->has('search')) {
            $search = trim($request->input('search'));
            $query = $query->where('sku', 'LIKE', "%$search%");
        }
        $query =  $query->groupBy('sku');

        $missingSkusCountQuery = clone $query;
        $missingSkusCount = $missingSkusCountQuery->get();
        $missingSkusCount =count($missingSkusCount);

        $missingSkus = $query->paginate(15);
        $data = [
          'missingSkus'  => $missingSkus,
          'missingSkusCount'  => $missingSkusCount,
          'currentPage'  => $currentPage,
      ];
         return view('purchase-order.add-inventory')
       ->with( $data);
    }
    
    public function addMissingSKUInInventory(Request $request)
    {
      $data = $request->validate([
        'title'=>'required',
        'cost'=>'required|regex:/^\d*(\.\d{1,2})?$/',
        'msku'=>'required',
      ]);
      $msku = $data['msku'];
      Inventory::create( $data);

       PurchaseOrder::where('sku', $msku)
      ->update(['is_available' => 1]);

      return redirect()->back()->with([
           "class" => "success",
           "text" => "SKU added successfully.",
       ]);
    }
    
    public function addMissingShipment(Request $request)
    {
      $data = $request->validate([
        'cost'=>'required|regex:/^\d*(\.\d{1,2})?$/',
        'tracking_number'=>'required',
      ]);
      Shipment::create( $data);

      return redirect()->back()->with([
           "class" => "success",
           "text" => "Shipment added successfully.",
       ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $shipment = Shipment::findOrFail($id);
        return view('shipment.edit',compact('shipment'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
          $data = $request->validate([
            'cost'=>'required',
        ]);
        $shipment = Shipment::findOrFail($id);  
        $shipment->update($data);
        return redirect()->route('shipment.missing')->with([
           "class" => "success",
           "text" => "Shipment updated successfully.",
       ]);
    }

}
