<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Exports\UsersExport;
use Maatwebsite\Excel\Facades\Excel;


use App\PurchaseOrder;
use App\Inventory;

use \stdClass;
use \DateTime;

class ReportController extends Controller
{
        private $months = [
            "Jan",
            "Feb",
            "Mar",
            "Apr",
            "May",
            "Jun",
            "Jul",
            "Aug",
            "Sep",
            "Oct",
            "Nov",
            "Dec"
        ];

    function gerYears(){
        
        $years_to_show = array();
        
        for ($j = 0; $j <= 10; $j++) {
            array_push($years_to_show, date("Y", strtotime(" -$j year")));
        }
        return $years_to_show;
    }

    function groupByTrackingNumber($input){
        $reportArray = [];
        $orderItems = [];
        $commission_percent = 0.15;
        foreach ($input as $key=>$data) { 
           
            $po_number = $data->po_number;
            $order_number = $data->order_number;
            $qty = (int) $data->qty;
            $sku = $data->sku;
            $shipping_cost = (float) $data->shipment->cost;

            $item_cost = (float) $data->inventory->cost;
            $item_sales_price = (float) $data->item_cost;
            $total_cost = $qty * $item_cost;

            $sales_price = $item_sales_price * $qty;
            $total_sales_price =  $sales_price;
            $tracking_number = $data->tracking_number;

            $item_description = $data->item_description;

            $itemDetails = new stdClass();
            $itemDetails->po_number = $po_number;
            $itemDetails->tracking_number = $tracking_number;
            $itemDetails->qty = $qty;
            $itemDetails->item_cost = $item_cost;
            $itemDetails->sale_price = $item_sales_price;
            $itemDetails->item_description = $item_description;
            $itemDetails->sku = $sku;

            if (isset($orderItems[$tracking_number])){
                $orderItems[$tracking_number][] = $itemDetails;
            }
            else {
                $item = array();
                $item[] = $itemDetails;
                $orderItems[$tracking_number] =  $item;
            }
            
            if(array_key_exists($po_number,$reportArray)){
                $existing_data = $reportArray[$po_number];
                $existing_data->total_cost += $total_cost;
                $existing_data->total_sales_price += $sales_price;
                $existing_data->qty += $qty;
                $existing_data->sku = $existing_data->sku .', '. $sku;
                $existing_data->item_description = $existing_data->item_description .', '. $sku;
            }
            else{
                $obj = new stdClass();
                $obj->po_number = $po_number;
                $obj->order_number = $order_number;
                $obj->order_date = $data->order_date;
                $obj->tracking_number = $tracking_number;
                $obj->ship_by = $data->ship_by;
                $obj->delivery_date = $data->delivery_date;
                $obj->customer_name = $data->customer_name;
                $obj->status = $data->status;
                $obj->item_description = $item_description;
                $obj->qty = $qty;
                $obj->sku = $sku;
                $obj->total_sales_price = $sales_price;
                $obj->total_cost = $total_cost;
                $obj->shipping_cost = $shipping_cost;
                $reportArray[$po_number] = $obj;
            }

        }
        $finalObj = new stdClass();
        $finalArray = [];
        $summaryRow = new stdClass();
        $summaryRow->qty = 0;
        $summaryRow->cost_total = 0;
        $summaryRow->sales_price_total = 0;
        $summaryRow->shipping_cost_total = 0;
        $summaryRow->commission_total = 0;
        $summaryRow->expenses_total = 0;
        $summaryRow->profit_or_loss_total = 0;

        foreach ($reportArray as $key=>$data) { 
            $total_sales_price = $data->total_sales_price;
            $total_cost = $data->total_cost;
            $commission = $total_sales_price * $commission_percent;
            $shipping_cost = $data->shipping_cost;
            $data->commission = number_format((float) $commission , 2, '.', '');
            $total_expenses = $data->total_cost + $shipping_cost + $commission;
            $data->total_expenses = number_format((float) $total_expenses , 2, '.', '');
            $profit_or_loss = $total_sales_price - $total_expenses; 
            $data->profit_or_loss = number_format((float) $profit_or_loss , 2, '.', '');
            $profit_percent = $profit_or_loss / $total_sales_price;
            $data->profit_percent = number_format((float) $profit_percent * 100, 2, '.', '');
            $ROI = 0;
             if($total_cost != 0){
                $ROI = $profit_or_loss / $total_cost;
            }
           
            $data->ROI = number_format((float) $ROI * 100, 2, '.', '');

            $summaryRow->qty += $data->qty;
            $summaryRow->cost_total += $data->total_cost;
            $summaryRow->sales_price_total += $total_sales_price;
            $summaryRow->shipping_cost_total += $shipping_cost;
            $summaryRow->commission_total += $commission;
            $summaryRow->expenses_total += $total_expenses;
            $summaryRow->profit_or_loss_total += $profit_or_loss;

            array_push($finalArray, $data);
        }
        $finalObj->summaryRow = $summaryRow;
        $finalObj->report = $finalArray;
        $finalObj->orderItems = $orderItems;
        return $finalObj;
    }
    
    public function index(Request $request)
    {
        $currentPage = $request['page'];
        $months = $this->months;
        $years = $this->gerYears();
        $summary_row_data = [];
        $selected_values = [];
        $report_data = [];
        $commission_percent = 0.15;
        $sales_price_total = 0;
        $cost_total = 0;
        $shipping_cost_total = 0;
        $commission_total = 0;
        $expenses_total = 0;
        $profit_or_loss_total = 0;
        $current_year = date("Y");
        $report_name = "";
        $selected_month = $request->input('month');
        $selected_year = $request->input('year');
        $selected_po = $request->input('po');
        $results = PurchaseOrder::whereHas("shipment")->with('inventory')->with('shipment');

        if ($request->has('month') && $request->has('year')) {
             $results = $results->whereMonth('order_date', $selected_month)->whereYear('order_date', $selected_year);
             $selected_values["year"] = $selected_year;    
             $selected_values["month"] = $selected_month;    
             $selected_values["download"] = 'active'; 
             $report_name = $selected_month ."_". $selected_year;
         }
        else
        if ($request->has('month')) {
             $results = $results->whereMonth('order_date', $selected_month);
             $selected_values["download"] = 'active';    
             $selected_values["month"] = $selected_month;  
             $report_name = $selected_month;  
        }
        else 
        if ($request->has('year')) {
             $selected_values["download"] = 'active';    
             $selected_values["year"] = $selected_year;    
             $results = $results->whereYear('order_date', $selected_year);
             $report_name = $selected_year;
        } 
        
        if ($request->has('po')) { 
             $results = $results->whereIn('po_number', explode(',',$selected_po));
        }

        $results = $results->where('is_available', 1);
        $pagging = clone $results;
        $pagging = $pagging->select('tracking_number')->groupBy('tracking_number')->paginate(15);
        $trackingNumbersArray = array();
        foreach ($pagging as $key=>$data) { $trackingNumbersArray[] = $data->tracking_number;}
        $results_sum = $results->whereIn('tracking_number', $trackingNumbersArray)->get();
      
         $mergedData = $this->groupByTrackingNumber($results_sum);
        $report_data = $mergedData->report;
        $summary_row_data = $mergedData->summaryRow;
        $orderItems = $mergedData->orderItems;
        
        if ($request->has('download')) {
            $report_data_array = [];
            foreach($report_data as $object)
            {
                unset($object->qty);
                unset($object->sku);
                unset($object->item_description);

                $report_data_array[] =  (array) $object;
            }
            $last_row = [
                '',
                '',
                '',
                '',
                '',
                '',
                '',
                'Totals',
                number_format((float) $summary_row_data->sales_price_total, 2, '.', ''),
                number_format((float) $summary_row_data->cost_total, 2, '.', ''),
                number_format((float) $summary_row_data->shipping_cost_total, 2, '.', ''),
                number_format((float) $summary_row_data->commission_total, 2, '.', ''),
                number_format((float) $summary_row_data->expenses_total, 2, '.', ''),
                number_format((float) $summary_row_data->profit_or_loss_total, 2, '.', '')
            ];
            array_push($report_data_array, $last_row);
            $export = new UsersExport([
                $report_data_array
            ]);
        
            $report_name = 'report_data_'. $report_name . '.xlsx';
            return Excel::download($export, $report_name);
        }
        $data = [
            'report'  => $report_data,
            'months'  => $months,
            'years'   => $years,
            'selected_values'   =>  $selected_values,
            'pagging' => $pagging,
            'summary_row_data' => $summary_row_data,
            'currentPage' => $currentPage,
            'orderItems' => $orderItems
        ];
       return view('report.index')->with($data);
   
    }


     function getReportData($results, $identifier = ""){
        $yearly_array = [];
        $commission_percent = 0.15;
        $sales_price_total = 0;
        $cost_total = 0;
        $shipping_cost_total = 0;
        $commission_total = 0;
        $expenses_total = 0;
        $profit_or_loss_total = 0;
        $total_qty = 0;


        foreach ($results as $key=>$data) {
             if (!isset($data->shipment) || !isset($data->inventory)) {
                dd($data);
            }

            $shipping_cost = (float) $data->shipment->cost;
            $item_cost = (float) $data->inventory->cost;
            $title = $data->inventory->title;
            $object = new stdClass();
            $sales_price = (float) $data->item_cost;
            // SUM of sales price
            $sales_price_total += $sales_price;

            
            $total_qty += (float) $data->qty;

            // Calculated values

            $total_cost = (float) $data->qty * $item_cost;
            // SUM of total cost
            $cost_total +=  $total_cost;
            $shipping_cost_total += (float) $shipping_cost;

            $commission =  $sales_price * $commission_percent;
            // SUM commission
            $commission_total += $commission;
            $total_expenses = $total_cost + $shipping_cost + $commission; 
            // SUM total expenses
            $expenses_total += $total_expenses;
            $profit_or_loss = $sales_price - $total_expenses;
            $profit_or_loss_total += $profit_or_loss;
            $profit_percent = 0;
            if($sales_price != 0){
                $profit_percent = $profit_or_loss / $sales_price;
            }

            $ROI = 0;
             if($total_cost != 0){
                $ROI = $profit_or_loss / $total_cost;
            }

            if($identifier !=  ""){
                $month = "";
                if($identifier ==  "skuReport"){
                    $month = $data->sku;
                   
                }
                else{
                $timestamp = strtotime($data->order_date);
                    $month = date('M', $timestamp);
                }

                if(array_key_exists($month,$yearly_array)){
                    $existing_data = $yearly_array[$month];
                    //dd($existing_data);
                    $existing_data->sales_price_total += $sales_price;
                    $existing_data->shipping_cost_total += $shipping_cost;
                    $existing_data->commission_total += $commission;
                    $existing_data->expenses_total += $total_expenses;
                    $existing_data->cost_total += $total_cost;
                    $existing_data->profit_or_loss_total += $profit_or_loss;
                    $existing_data->qty_total += (float) $data->qty;
                    $yearly_array[$month] = $existing_data;
                }
                else{
                    $obj = new stdClass();
                    $obj->sales_price_total = $sales_price;
                    $obj->title = $title;
                     $obj->shipping_cost_total = $shipping_cost;
                     $obj->commission_total = $commission;
                     $obj->expenses_total = $total_expenses;
                     $obj->profit_or_loss_total = $profit_or_loss;
                     $obj->qty_total = (float) $data->qty;
                     $obj->cost_total = $total_cost;
                    $yearly_array[$month] = $obj;
                }
            }
        }
          if($identifier ==  ""){

                $summary_row_object = new stdClass();
                $summary_row_object->sales_price_total =  number_format((float) $sales_price_total, 2, '.', ',');
                $summary_row_object->shipping_cost_total =  number_format((float) $shipping_cost_total, 2, '.', ',');
                $summary_row_object->commission_total =  number_format((float) $commission_total, 2, '.', ',');
                $summary_row_object->expenses_total =  number_format((float) $expenses_total, 2, '.', ',');
                $summary_row_object->profit_or_loss_total =  number_format((float) $profit_or_loss_total, 2, '.', ',');
                $summary_row_object->qty =  number_format((float) $total_qty, 2, '.', ',');
               
                return $summary_row_object;

            }
            else{
                return $yearly_array;
            }
     
     }
    
     public function summary(Request $request){
        
         $selected_year = $request->input('year') ? $request->input('year') : date('Y');
        
        $years = $this->gerYears();
        $results = PurchaseOrder::whereHas("shipment")->with('inventory')->with('shipment')->where('is_available', 1)->whereYear('order_date', $selected_year)->orderByRaw('DATE_FORMAT(order_date, "%m")')->groupBy('tracking_number')->get();
    
       $count = count($results->toArray());
       $yearly_report = $this->getReportData($results, "Yearly");
           $data = [
            'yearly_report'  => $yearly_report,  
            'years'          => $years          
        ];
        $final_total = new stdClass();
        $final_total->qty_sum = 0; 
        $final_total->sale_price_sum = 0; 
        $final_total->cost_sum = 0; 
        $final_total->shipping_cost_sum = 0; 
        $final_total->commission_sum = 0; 
        $final_total->total_exp_sum = 0; 
        $final_total->profit_loss_sum = 0; 
       foreach ($yearly_report as $key => $obj){
        $final_total->qty_sum += $obj->qty_total;
        $final_total->sale_price_sum += $obj->sales_price_total;
        $final_total->cost_sum += $obj->cost_total;
        $final_total->shipping_cost_sum += $obj->shipping_cost_total;
        $final_total->commission_sum += $obj->commission_total;
        $final_total->total_exp_sum += $obj->expenses_total;
        $final_total->profit_loss_sum += $obj->profit_or_loss_total;
       }
       $data["final_totals"] = $final_total;
       return view('report.summary')->with( $data);
    }
    
     public function skuReport(Request $request){
        $inventories = Inventory::all();
        $inventories = $inventories->toArray();
        $selected_values = [];
        $inventory_ids_arr = [];
        $selected_month = $request->input('month');
        $selected_year = $request->input('year');
        $inventory_ids = $request->input('skus');
       
        $results = PurchaseOrder::whereHas("shipment")->with('inventory')->with('shipment')->where('is_available', 1)->selectRaw(' id, tracking_number, sku, sum(item_cost) as item_cost, sum(qty) as qty');
        
        if ($request->has('month') && $request->has('year')) {
            $results = $results->whereMonth('order_date', $selected_month)->whereYear('order_date', $selected_year);
            $selected_values["year"] = $selected_year;    
            $selected_values["month"] = $selected_month;          
        }
        if ($request->has('skus')) {
            $inventory_ids_arr = explode(',', $inventory_ids);
           $skus = Inventory::select("msku")->whereIn('id', $inventory_ids_arr)->pluck("msku");
          // dd($skus);
            $results = $results->whereIn('sku', $skus);       
        }

        $results = $results->groupBy('sku')->paginate(15);
       $yearly_report = $this->getReportData($results, "skuReport");
           $data = [
            'results'           => $results,  
            'yearly_report'     => $yearly_report,  
            'years'             => $this->gerYears(),         
            'months'            => $this->months, 
            'selected_values'   =>  $selected_values,        
            'inventories'   =>  $inventories,        
            'inventory_ids_arr'   =>  $inventory_ids_arr,        
        ];
        $final_total = new stdClass();
        $final_total->qty_sum = 0; 
        $final_total->sale_price_sum = 0; 
        $final_total->cost_sum = 0; 
        $final_total->shipping_cost_sum = 0; 
        $final_total->commission_sum = 0; 
        $final_total->total_exp_sum = 0; 
        $final_total->profit_loss_sum = 0; 
       foreach ($yearly_report as $key => $obj){
        $final_total->qty_sum += $obj->qty_total;
        $final_total->sale_price_sum += $obj->sales_price_total;
        $final_total->cost_sum += $obj->cost_total;
        $final_total->shipping_cost_sum += $obj->shipping_cost_total;
        $final_total->commission_sum += $obj->commission_total;
        $final_total->total_exp_sum += $obj->expenses_total;
        $final_total->profit_loss_sum += $obj->profit_or_loss_total;
       }
       $data["final_totals"] = $final_total;
       return view('report.sku-summary')->with( $data);
    }
}
