<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Shipment;


class ShipmentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $currentPage = $request['page'];
         $query = Shipment::whereNotNull('cost');
      
        if ( $request->has('search')) {
            $search = trim($request->input('search'));
            $query = $query->where('tracking_number', 'LIKE', "%$search%");
            $query = $query->orWhere('recipient', 'LIKE', "%$search%");
            $query = $query->orWhere('created_date', 'LIKE', "%$search%");
        }

         $shipments = $query->paginate(15);
         $data = [
            'shipments'  => $shipments,
            'currentPage'  => $currentPage,
        ];
         return view('shipment.index')
       ->with( $data);
    }

    public function missing()
    {
         $shipments = Shipment::whereNull('cost')->paginate(15);
         return view('shipment.index')
       ->withShipments( $shipments);
    }
    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {

        $shipment = Shipment::findOrFail($id);
        return view('shipment.edit',compact('shipment'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
          $data = $request->validate([
            'cost'=>'required',
        ]);
        $shipment = Shipment::findOrFail($id);  
        $shipment->update($data);
        return redirect()->route('shipment.missing')->with([
           "class" => "success",
           "text" => "Shipment updated successfully.",
       ]);
    }

}
